@@ -11,7 +11,7 @@ Task::Sites::ShlomiFish - Specifications for modules needed for building www.shl
 
 =cut
 
-our $VERSION = '0.0213';
+our $VERSION = '0.0214';
 
 =head1 DESCRIPTION
 
@@ -91,10 +91,6 @@ You can also look for information at:
 
 =over 4
 
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Task-Sites-ShlomiFish>
-
 =item * CPAN Ratings
 
 L<http://cpanratings.perl.org/d/Task-Sites-ShlomiFish>
